abacusai.web_page_response — AbacusAI documentation

# abacusai.web_page_response

## Classes

`WebPageResponse` | A scraped web page response

## Module Contents

class abacusai.web_page_response.WebPageResponse(client, content=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  A scraped web page response

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - content (str) – The content of the web page.

  content = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict